task somaticFilter {
  
  String sample
  File varscan_snp_somatic_hc
  File varscan_snp_germline_hc
  File varscan_snp_loh_hc
  File varscan_indel_somatic_hc
  File varscan_indel_germline_hc
  File varscan_indel_loh_hc
  File varscan_indel

  String docker
  String cluster_config
  String disk_size

  command <<<
    java -Xmx32g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${varscan_snp_somatic_hc} --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --indel-file ${varscan_indel} --output-file ${sample}.VarScan.SNP.Somatic.filter.vcf

    java -Xmx32g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${varscan_snp_germline_hc} --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --indel-file ${varscan_indel} --output-file ${sample}.VarScan.SNP.Germline.filter.vcf

    java -Xmx32g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${varscan_snp_loh_hc} --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --indel-file ${varscan_indel} --output-file ${sample}.VarScan.SNP.LOH.filter.vcf

    java -Xmx32g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${varscan_indel_somatic_hc} --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --output-file ${sample}.VarScan.INDEL.Somatic.filter.vcf

    java -Xmx32g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${varscan_indel_germline_hc} --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --output-file ${sample}.VarScan.INDEL.Germline.filter.vcf

    java -Xmx32g -jar /opt/VarScan.v2.4.3.jar somaticFilter ${varscan_indel_loh_hc} --min-coverage 10 --min-reads2 2 --min-strands2 1 --min-avg-qual 20 --p-value 0.1 --output-file ${sample}.VarScan.INDEL.LOH.filter.vcf

    # Merge SNP and INDEL
    awk '{if ($1!~/^#/) print}' ${sample}.VarScan.SNP.Somatic.filter.vcf | cat ${sample}.VarScan.INDEL.Somatic.filter.vcf - > ${sample}.VarScan.Somatic.filter.vcf
    awk '{if ($1!~/^#/) print}' ${sample}.VarScan.SNP.Germline.filter.vcf | cat ${sample}.VarScan.INDEL.Germline.filter.vcf - > ${sample}.VarScan.Germline.filter.vcf
    awk '{if ($1!~/^#/) print}' ${sample}.VarScan.SNP.LOH.filter.vcf | cat ${sample}.VarScan.INDEL.LOH.filter.vcf - > ${sample}.VarScan.LOH.filter.vcf
  >>>

  runtime {
    docker: docker
    cluster: cluster_config
    systemDisk: "cloud_ssd 40"
    dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
  }

  output {
		File varscan_somatic_filter = "${sample}.VarScan.Somatic.filter.vcf"
    File varscan_germline_filter = "${sample}.VarScan.Germline.filter.vcf"
		File varscan_loh_filter = "${sample}.VarScan.LOH.filter.vcf"
  }
}